# cours-maths-nsi

latexcor need latexmk

pip install --upgrade latexcor

## command

latexcor

latexcor --clean

latexcor --recompile

latexcor --xelatex

latexcor --lualatex

latexcor --utf8

latexcor --slugify

## Ajouter texmf

```bash
sudo tlmgr conf auxtrees add ~/texmf
```
